#!/usr/bin/python3
import os
import sys


def get_job_ad():
    instream = sys.stdin
    job_ad = {}
    # format of the job ad is key = value
    for line in instream:
        if " = " in line:
            key = line.split(" = ")[0]
            value = line.replace(f"{key} = ", "")
            job_ad[key.strip().replace('"', "")] = value.strip().replace('"', "")
    return job_ad


def sanitize_image_name(image):
    domain = ""
    # remove docker:// prefix
    if not image.startswith("/cvmfs/"):
        if image.startswith("docker://"):
            image = image.replace("docker://", "")
        # try to identify the domain if there is any
        if image.count("/") >= 2:
            domain = image.split("/")[0]
            image = image.replace(domain + "/", "")
        else:
            # assume dockerhub for domain
            domain = "registry.hub.docker.com"
    # if no tag is provided, add latest
    if ":" not in image:
        image = image + ":latest"
    return domain, image


def construct_image_path(domain, imagename):
    if imagename.startswith("/cvmfs/"):
        return imagename
    else:
        return f"/cvmfs/unpacked.cern.ch/{domain}/{imagename}"


def check_image_availability(image_path):
    if os.path.exists(image_path):
        return True
    else:
        return False


def main():
    job_ad = get_job_ad()
    status_message = ""
    condor_arg = ""
    job_ad["WantDocker"] = "false"
    # write job_ad to a file for debugging
    dumpfilepath = "/scratch/job_ad_initial.json"
    with open(dumpfilepath, "w") as f:
        for key, value in job_ad.items():
            f.write(f"{key} = {value}\n")
    container_image = job_ad.get("ContainerImage")
    docker_image = job_ad.get("DockerImage")

    if not container_image and not docker_image:
        job_ad["status_message"] = (
            "No container image provided, using default container: /cvmfs/unpacked.cern.ch/registry.hub.docker.com/mschnepf/slc7-condocker:latest"
        )
        # return the default container image to stdout
        job_ad["ContainerImage"] = (
            "/cvmfs/unpacked.cern.ch/registry.hub.docker.com/mschnepf/slc7-condocker:latest"
        )
    else:
        # pick the args parameter that is not None
        image = container_image or docker_image
        domain, imagename = sanitize_image_name(image)
        image_path = construct_image_path(domain, imagename)
        if check_image_availability(image_path):
            condor_arg = image_path
        else:
            condor_arg = f"docker://{domain}/{imagename}"
        job_ad["ContainerImage"] = condor_arg
        job_ad["status_message"] = f"Container image set to {image_path} via hook"
    # return the results via stdout
    print(f'ContainerImage = "{job_ad["ContainerImage"]}"', file=sys.stdout)
    print(f"WantDocker = {job_ad['WantDocker']}", file=sys.stdout)
    print(f'HookStatusMessage = "{job_ad["status_message"]}"', file=sys.stdout)
    # dump the updated job ad to a file for debugging
    dumpfilepath = "/scratch/job_ad_updated.json"
    with open(dumpfilepath, "w") as f:
        for key, value in job_ad.items():
            f.write(f"{key} = {value}\n")
    print(f"HookStatusMessage = {status_message}", file=sys.stdout)


if __name__ == "__main__":
    main()
